@@ -14,9 +14,31 @@ use ArangoDB2::HTTP::LWP;
 # a particular HTTP client
 sub new
 {
-    my $self = shift;
-    # for now use LWP client
-    return ArangoDB2::HTTP::LWP->new(@_);
+    my($self, $arango) = @_;
+
+    # see if specific http client is set
+    if (my $http_client = $arango->http_client) {
+        if ($http_client eq 'lwp') {
+            return ArangoDB2::HTTP::LWP->new($arango);
+        }
+        elsif ($http_client eq 'curl') {
+            require ArangoDB2::HTTP::Curl;
+            return ArangoDB2::HTTP::Curl->new($arango);
+        }
+    }
+
+    # if no client was set then use curl if possible
+    # and if not fall back to LWP
+    my $curl = eval { require WWW::Curl::Easy };
+
+    if ($curl) {
+        require ArangoDB2::HTTP::Curl;
+        return ArangoDB2::HTTP::Curl->new($arango);
+    }
+    else {
+        # for now use lwp client
+        return ArangoDB2::HTTP::LWP->new($arango);
+    }
 }
 
 # arango
